@@ -54,6 +54,7 @@ mmap_cache * mmc_new() {
 
   cache->fh = 0;
   cache->share_file = _mmc_get_def_share_filename(cache);
+  cache->permissions = 0640;
   cache->init_file = def_init_file;
   cache->test_file = def_test_file;
 
@@ -78,6 +79,8 @@ int mmc_set_param(mmap_cache * cache, char * param, char * val) {
     cache->expire_time = atoi(val);
   } else if (!strcmp(param, "share_file")) {
     cache->share_file = val;
+  } else if (!strcmp(param, "permissions")) {
+    cache->permissions = atoi(val);
   } else if (!strcmp(param, "start_slots")) {
     cache->start_slots = atoi(val);
   } else if (!strcmp(param, "catch_deadlocks")) {
@@ -1141,10 +1144,10 @@ int  _mmc_test_page(mmap_cache * cache) {
       MU32 kvlen = S_SlotLen(base_det);
       ROUNDLEN(kvlen);
 
-      ASSERT(last_access > 1000000000 && last_access < 1500000000);
-      if (!(last_access > 1000000000 && last_access < 1500000000)) return 0;
-      ASSERT(expire_time == 0 || (expire_time > 1000000000 && expire_time < 1500000000));
-      if (!(expire_time == 0 || (expire_time > 1000000000 && expire_time < 1500000000))) return 0;
+      ASSERT(last_access > 1000000000)
+      if (!(last_access > 1000000000)) return 0;
+      ASSERT(expire_time == 0 || (expire_time > 1000000000));
+      if (!(expire_time == 0 || (expire_time > 1000000000))) return 0;
 
       ASSERT(key_len >= 0 && key_len < data_size);
       if (!(key_len >= 0 && key_len < data_size)) return 0;
